@@ -308,6 +308,8 @@ def main(args):
     parser.add_argument(
         '--remove', help='TSV ID GeneName Product file to remove from annotation')
     parser.add_argument('--rename', help='Rename locus tag')
+    parser.add_argument('--no-progress', dest='progress', action='store_false',
+                        help='no progress on multiprocessing')
     args = parser.parse_args(args)
 
     global parentdir, IPR2ANNOTATE, FUNDB
@@ -434,12 +436,9 @@ def main(args):
             else:
                 Scaffolds = args.fasta
                 GFF = args.gff
-                Proteins = os.path.join(
-                    outputdir, 'annotate_misc', 'genome.proteins.fa')
-                Transcripts = os.path.join(
-                    outputdir, 'annotate_misc', 'genome.transcripts.fasta')
-                annotTBL = os.path.join(
-                    outputdir, 'annotate_misc', 'genome.tbl')
+                Proteins = os.path.join(outputdir, 'annotate_misc', 'genome.proteins.fa')
+                Transcripts = os.path.join(outputdir, 'annotate_misc', 'genome.transcripts.fasta')
+                annotTBL = os.path.join(outputdir, 'annotate_misc', 'genome.tbl')
                 prefix = None
                 if args.rename:
                     prefix = args.rename.replace('_', '')
@@ -449,12 +448,9 @@ def main(args):
                     GFF, prefix, Scaffolds, Proteins, Transcripts, annotTBL, external=True)
         else:
             genbank = args.genbank
-            Scaffolds = os.path.join(
-                outputdir, 'annotate_misc', 'genome.scaffolds.fasta')
-            Proteins = os.path.join(
-                outputdir, 'annotate_misc', 'genome.proteins.fasta')
-            Transcripts = os.path.join(
-                outputdir, 'annotate_misc', 'genome.transcripts.fasta')
+            Scaffolds = os.path.join(outputdir, 'annotate_misc', 'genome.scaffolds.fasta')
+            Proteins = os.path.join(outputdir, 'annotate_misc', 'genome.proteins.fasta')
+            Transcripts = os.path.join(outputdir, 'annotate_misc', 'genome.transcripts.fasta')
             GFF = os.path.join(outputdir, 'annotate_misc', 'genome.gff3')
             annotTBL = os.path.join(outputdir, 'annotate_misc', 'genome.tbl')
             lib.log.info("Checking GenBank file for annotation")
@@ -523,12 +519,9 @@ def main(args):
                 lib.log.error(
                     "Found existing output directory %s. Warning, will re-use any intermediate files found." % (outputdir))
             lib.log.info("Parsing input files")
-            Scaffolds = os.path.join(
-                outputdir, 'annotate_misc', 'genome.scaffolds.fasta')
-            Proteins = os.path.join(
-                outputdir, 'annotate_misc', 'genome.proteins.fasta')
-            Transcripts = os.path.join(
-                outputdir, 'annotate_misc', 'genome.transcripts.fasta')
+            Scaffolds = os.path.join(outputdir, 'annotate_misc', 'genome.scaffolds.fasta')
+            Proteins = os.path.join(outputdir, 'annotate_misc', 'genome.proteins.fasta')
+            Transcripts = os.path.join(outputdir, 'annotate_misc', 'genome.transcripts.fasta')
             if TBL:
                 lib.log.info('Existing tbl found: {:}'.format(TBL))
                 shutil.copyfile(TBL, annotTBL)
@@ -1318,12 +1311,20 @@ def main(args):
                         if sub_stop > record_end:
                             sub_stop = record_end
                         sub_record = record[sub_start:sub_stop]
+                        # this seems to be either py3 requirement or required in newer biopython
+                        sub_record.annotations = record.annotations
                         cluster_name = slice[1]
                         sub_record_name = os.path.join(
                             AntiSmashFolder, cluster_name+'.gbk')
                         Offset[cluster_name] = sub_start
                         with open(sub_record_name, 'w') as clusterout:
-                            SeqIO.write(sub_record, clusterout, 'genbank')
+                            try:
+                                SeqIO.write(sub_record, clusterout, 'genbank')
+                            except ValueError:
+                                print(slice)
+                                print(subrecord.id)
+                                print(sub_record.annotations)
+                                sys.exit(1)
 
         # okay, now loop through each cluster
         for file in os.listdir(AntiSmashFolder):
