@@ -60,10 +60,13 @@ def main(args):
                         choices=['raxml', 'iqtree'], help='ML method')
     parser.add_argument('-d', '--database',
                         help='Path to funannotate database, $FUNANNOTATE_DB')
+    parser.add_argument('--no-progress', dest='progress', action='store_false',
+                        help='no progress on multiprocessing')
     args = parser.parse_args(args)
 
     parentdir = os.path.join(os.path.dirname(__file__))
 
+
     # setup funannotate DB path
     if args.database:
         FUNDB = args.database
@@ -71,16 +74,15 @@ def main(args):
         try:
             FUNDB = os.environ["FUNANNOTATE_DB"]
         except KeyError:
-            lib.log.error(
-                'Funannotate database not properly configured, run funannotate setup.')
+            print('ERROR: Funannotate database not properly configured, run funannotate setup.')
             sys.exit(1)
 
     # check database sources, so no problems later
-    sources = [os.path.join(FUNDB, 'Pfam-A.clans.tsv'), os.path.join(FUNDB,
-                                                                     'interpro.xml'), os.path.join(FUNDB, 'go.obo')]
+    sources = [os.path.join(FUNDB, 'Pfam-A.clans.tsv'),
+               os.path.join(FUNDB, 'interpro.tsv'),
+               os.path.join(FUNDB, 'go.obo')]
     if not all([os.path.isfile(f) for f in sources]):
-        lib.log.error(
-            'Database files not found in %s, run funannotate database and/or funannotate setup' % FUNDB)
+        print('ERROR: Database files not found in %s, run funannotate database and/or funannotate setup' % FUNDB)
         sys.exit(1)
 
     # remove slashes if they exist in output
@@ -994,11 +996,13 @@ def main(args):
         dNdSList = lib.get_subdirs(ortho_folder)
         if args.run_dnds == 'estimate':
             lib.log.debug("Running simple dN/dS estimate")
-            lib.runMultiProgress(lib.rundNdSestimate, dNdSList, args.cpus)
+            lib.runMultiProgress(lib.rundNdSestimate, dNdSList, args.cpus,
+                                 progress=args.progress)
         else:
             lib.log.debug(
                 "Running exhasitve dN/dS ratio with Likelihood Ratio Tests")
-            lib.runMultiProgress(lib.rundNdSexhaustive, dNdSList, args.cpus)
+            lib.runMultiProgress(lib.rundNdSexhaustive, dNdSList, args.cpus,
+                                 progress=args.progress)
 
         # after all data is run, then parse result log files, return dictionary
         dNdSresults = lib.parsedNdS(ortho_folder)
